% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/models.r
\name{pull_model}
\alias{pull_model}
\alias{show_model}
\alias{delete_model}
\alias{copy_model}
\title{Pull, show and delete models}
\usage{
pull_model(
  model = NULL,
  server = NULL,
  insecure = FALSE,
  verbose = getOption("rollama_verbose", default = interactive())
)

show_model(model = NULL, server = NULL)

delete_model(model, server = NULL)

copy_model(model, destination = paste0(model, "-copy"), server = NULL)
}
\arguments{
\item{model}{name of the model(s). Defaults to "llama3.1" when \code{NULL} (except
in \code{delete_model}).}

\item{server}{URL to one or several Ollama servers (not the API). Defaults to
"http://localhost:11434".}

\item{insecure}{allow insecure connections to the library. Only use this if
you are pulling from your own library during development.}

\item{verbose}{Whether to print status messages to the Console. Either
\code{TRUE}/\code{FALSE} or see \link[httr2:progress_bars]{httr2::progress_bars}. The default is to have status
messages in interactive sessions. Can be changed with
\code{options(rollama_verbose = FALSE)}.}

\item{destination}{name of the copied model.}
}
\value{
(invisible) a tibble with information about the model (except in
\code{delete_model})
}
\description{
Pull, show and delete models
}
\details{
\itemize{
\item \code{pull_model()}: downloads model
\item \code{show_model()}: displays information about a local model
\item \code{copy_model()}: creates a model with another name from an existing model
\item \code{delete_model()}: deletes local model
}

\strong{Model names}: Model names follow a model:tag format, where model can have
an optional namespace such as example/model. Some examples are
orca-mini:3b-q4_1 and llama3.1:70b. The tag is optional and, if not provided,
will default to latest. The tag is used to identify a specific version.
}
\examples{
\dontrun{
# download a model and save information in an object
model_info <- pull_model("mixtral")
# after you pull, you can get the same information with:
model_info <- show_model("mixtral")
# pulling models from Hugging Face Hub is also possible
pull_model("https://huggingface.co/oxyapi/oxy-1-small-GGUF:Q2_K")
}
}
